@@ -3,5 +3,6 @@ __doc__  = """Machine Learning toolbox.
 Subpackage dedicated to Machine Learning helpers.
 """
 
-from pyspark_ds_toolbox.ml import data_prep, shap_values
-from pyspark_ds_toolbox.ml.classification import eval, baseline_classifiers
\ No newline at end of file
+from pyspark_ds_toolbox.ml import data_prep
+from pyspark_ds_toolbox.ml.classification import eval, baseline_classifiers
+from pyspark_ds_toolbox.ml.feature_importance import shap_values
\ No newline at end of file
